@@ -1,5 +1,5 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "org-arbeitszeit" "0.0.5"
+(define-package "org-arbeitszeit" "20250724.1857"
   "Calculate your worktime."
   '((emacs "27.1"))
   :url "https://github.com/bkaestner/org-arbeitszeit"
